@@ -2,6 +2,7 @@ from __future__ import print_function   # makes this work for python2 and 3
 
 import unittest
 import inspect
+import os 
 import numpy as np
 import gvar as gv
 import lsqfit
@@ -202,6 +203,24 @@ class test_multifitter(unittest.TestCase):
         fit2 = fitter.lsqfit(data=self.data, prior=self.prior)
         self.assertEqual(self.ref_fit.format(), fit2.format())
 
+    def test_lsqfit_p0(self):
+        " MultiFitter.lsqfit with p0 "
+        fitter = MultiFitter(models=self.make_models(ncg=1))
+        p0 = {'a': 0.9992476083689589,'b': 0.4996757090188109}
+        fit2 = fitter.lsqfit(data=self.data, prior=self.prior, p0=p0)
+        self.assertEqual(self.ref_fit.format()[:-20], fit2.format()[:-20])
+        self.assertEqual(p0, fit2.p0)
+        fit2 = fitter.lsqfit(data=self.data, prior=self.prior, p0=3 * [p0])
+        self.assertEqual(self.ref_fit.format()[:-20], fit2.format()[:-20])
+        self.assertEqual(p0, fit2.p0)
+        fn = 'test_multifitter.p'
+        fit1 = fitter.lsqfit(data=self.data, prior=self.prior, p0=fn)
+        fit2 = fitter.lsqfit(data=self.data, prior=self.prior, p0=fn)
+        self.assertEqual(self.ref_fit.format()[:-20], fit2.format()[:-20])
+        self.assertEqual(fit1.pmean, fit2.p0)
+        os.unlink(fn)
+
+
     def test_dump_lsqfit(self):
         " MultiFitter.lsqfit "
         fitter = MultiFitter(models=self.make_models(ncg=1))
@@ -285,6 +304,28 @@ class test_multifitter(unittest.TestCase):
             # "{'log(a)': -0.00073(48),'b': 0.50015(82),'log(aa)': -0.00073(48)}"
             )
 
+    def test_chained_lsqfit_p0(self):
+        " MultiFitter.chained_lsqfit(...) "
+        # sequential fit
+        fitter = MultiFitter(models=self.make_models(ncg=1))
+        p0 = gv.BufferDict({'a': 0.9991638707908023,'b': 0.4995927960301173})
+        p0list = [p0, gv.BufferDict(a=0.9991638707908023), gv.BufferDict(a=0.9991638707908023)]
+        fit1 = fitter.chained_lsqfit(data=self.data, prior=self.prior, p0=p0)
+        self.assertEqual(str(fit1.p), "{'a': 0.99916(62),'b': 0.49959(94)}") # "{'a': 0.99929(48),'b': 0.49986(91)}")
+        self.assertEqual(list(fit1.chained_fits.keys()), ['l', 'c1', 'c2'])
+        self.assertEqual(fit1.p0, p0list)
+        fit1 = fitter.chained_lsqfit(data=self.data, prior=self.prior, p0=3 * [p0])
+        self.assertEqual(str(fit1.p), "{'a': 0.99916(62),'b': 0.49959(94)}") # "{'a': 0.99929(48),'b': 0.49986(91)}")
+        self.assertEqual(list(fit1.chained_fits.keys()), ['l', 'c1', 'c2'])
+        self.assertEqual(fit1.p0, p0list)
+        fn = 'test_multifitter.p'
+        fit1 = fitter.chained_lsqfit(data=self.data, prior=self.prior, p0=fn)
+        fit2 = fitter.chained_lsqfit(data=self.data, prior=self.prior, p0=fn)
+        self.assertEqual(str(fit1.p), "{'a': 0.99916(62),'b': 0.49959(94)}") # "{'a': 0.99929(48),'b': 0.49986(91)}")
+        self.assertEqual(list(fit1.chained_fits.keys()), ['l', 'c1', 'c2'])
+        self.assertEqual([f.pmean for f in fit1.chained_fits.values()], fit2.p0)
+        os.unlink(fn)
+         
     def test_dump_chained_lsqfit(self):
         " MultiFitter.chained_lsqfit(...) "
         # sequential fit
@@ -335,6 +376,22 @@ class test_multifitter(unittest.TestCase):
         self.assertEqual(str(fit5.p),  "{'a': 0.99918(61),'b': 0.49959(94)}") # "{'a': 0.99932(48),'b': 0.49986(91)}")
         self.assertEqual(list(fit5.chained_fits.keys()), ['l', 'c1', 'c2', 'wavg(c1,c2)'])
 
+        # degenerate parallel fit (nfit=1)
+        models = self.make_models(ncg=1)
+        models = [[models[0]], models[1:]]
+        fitter = MultiFitter(models=models)
+        fit5 = fitter.chained_lsqfit(data=self.data, prior=self.prior)
+        self.assertEqual(str(fit5.p),  "{'a': 0.99918(61),'b': 0.49959(94)}") # "{'a': 0.99932(48),'b': 0.49986(91)}")
+        self.assertEqual(list(fit5.chained_fits.keys()), ['l', 'c1', 'c2', 'wavg(c1,c2)'])
+
+        # dictionaries in parallel fits
+        models = self.make_models(ncg=1)
+        models = [[dict(svdcut=1e-12), models[0]], [dict(svdcut=1e-12)] + models[1:]]
+        fitter = MultiFitter(models=models)
+        fit5 = fitter.chained_lsqfit(data=self.data, prior=self.prior)
+        self.assertEqual(str(fit5.p),  "{'a': 0.99918(61),'b': 0.49959(94)}") # "{'a': 0.99932(48),'b': 0.49986(91)}")
+        self.assertEqual(list(fit5.chained_fits.keys()), ['l', 'c1', 'c2', 'wavg(c1,c2)'])
+
         # with coarse grain, marginalization
         models = self.make_models(ncg=2)
         models = [models[0], models[1:]]
